"""
PyDetex
https://github.com/ppizarror/PyDetex

PYDETEX
An application that transforms LaTeX code to plain text.
"""

import pydetex.version

__author__ = 'Pablo Pizarro R.'
__copyright__ = 'Copyright 2021 Pablo Pizarro R. @ppizarror'
__description__ = 'An application that transforms LaTeX code to plain text'
__email__ = 'pablo@ppizarror.com'
__keywords__ = 'latex detex parser gui'
__license__ = 'MIT'
__module_name__ = 'pydetex'
__url__ = 'https://pydetex.readthedocs.io'
__url_bug_tracker__ = 'https://github.com/ppizarror/PyDetex/issues'
__url_documentation__ = 'https://pydetex.readthedocs.io'
__url_source_code__ = 'https://github.com/ppizarror/PyDetex'
__version__ = pydetex.version.ver
